--
-- Database schema creation script: all tables and sequences are defined here.
-- MutaGeneSys
-- Author: Julia Stoyanovich (jds1@cs.columbia.edu)
-- October 25, 2007
--

-- sequences
create sequence ReqId_Seq start with 1 nocycle nomaxvalue nocache
/
create sequence IndId_Seq start with 1 nocycle nomaxvalue nocache
/
create sequence HapId_Seq start with 1 nocycle nomaxvalue nocache
/

-- auxiliary tables
create table Population (
  id         varchar2(16) primary key,
  name       varchar2(64)
)
/

create table Technology (
  id   		number,
  name 		varchar2(64),
  resolution 	number,
  primary key (id, resolution)
)
/

create table Stage (
  reqId    number,
  title    varchar2(256),
  href     varchar2(256)
)
/

-- data tables
create table OMIM (
  id      number primary key,
  title   varchar2(256)
)
/
 
create table SNP_OMIM_Map (
  snpId		varchar2(16),
  omimId	number,
  primary key (snpId, omimId),
  foreign key (omimId) references OMIM(id)
)
/

create table Single_OMIM_Map (
  techId number,
  resolution number,
  popId varchar2(16),
  srcSnpId varchar2(16),
  tgtSnpId varchar2(16),
  srcAllele char(1),
  tgtAllele char(1),
  coeff number,
  omimId number
)
/

create table Double_OMIM_Map (
  techId number,
  resolution number,
  popId varchar2(16),
  srcSnpId_1 varchar2(16),
  srcSnpId_2 varchar2(16),
  tgtSnpId varchar2(16),
  srcAllele_1 char(1),
  srcAllele_2 char(1),
  tgtAllele char(1),
  coeff number,
  omimId number
)
/

-- request/result tables
create table Individual (
  id             number primary key,
  gender      	 char,
  popId	         varchar2(16)
)
/

create table Haplotype (
  hapId      number,
  indId      number,
  snpId      varchar2(32),
  allele     char,
  primary key (indId, hapId, snpId),
  foreign key (indId) references Individual(id)
)
/

create table Request (
  reqId      number,
  indId      number,
  hapId      number,
  popId      varchar2(16),
  techId     number,
  resolution number,
  minConf    number,
  ts         date,
  primary key (reqId, hapId),
  foreign key (indId) references Individual(id),
  foreign key (popId) references Population(id),
  foreign key (techId, resolution) references Technology(id, resolution)
)
/

create table Result_Full (
  reqId     number,
  hapId     number,
  snpId_1   varchar2(16),
  snpId_2   varchar2(16),
  allele_1  char,
  allele_2  char,
  causal_snpId varchar2(16),
  causal_allele  char,
  techId    number,
  resolution number,
  popId     varchar2(16),
  coeff     number,
  omimId    number,
  zyg       varchar2(16),
  ts        date,
  foreign key (omimId) references OMIM(id),
  foreign key (reqId, hapId) references Request(reqId, hapId)
)
/

create table Result_Summary (
  reqId     number,
  hapId     number,
  snpId_1   varchar2(16),
  snpId_2   varchar2(16),
  omimId    number,
  title     varchar2(256),
  zyg       varchar2(16),
  ts        date,
  foreign key (omimId) references OMIM(id),
  foreign key (reqId, hapId) references Request(reqId, hapId)
)
/

create view SNPs_Used_B36 as (
  select distinct snpId from (
    select distinct srcSnpId snpId from Single_OMIM_map 
    UNION
    select distinct srcSnpId_1 snpId from Double_OMIM_map 
    UNION
    select distinct srcSnpId_2 snpId from Double_OMIM_map 
    UNION
    select distinct tgtSnpId snpId from Single_OMIM_map 
    UNION
    select distinct tgtSnpId snpId from Double_OMIM_map 
  )
)
/
